const svg = d3.select("svg"),
    margin = {top: 20, right: 20, bottom: 40, left: 50},
    width = +svg.attr("width") - margin.left - margin.right,
    height = +svg.attr("height") - margin.top - margin.bottom,
    g = svg.append("g").attr("transform", "translate(" + margin.left + "," + margin.top + ")");

const parseTime = d3.timeParse("%Y-%m-%d"),
      x = d3.scaleTime().rangeRound([0, width]),
      y = d3.scaleLinear().rangeRound([height, 0]);

const area = d3.area()
    .x(d => x(d.date))
    .y0(height)
    .y1(d => y(d.sales));

d3.csv("https://gist.githubusercontent.com/your-username/gist-id/raw/data.csv", d => {
  d.date = parseTime(d.Date);
  d.sales = +d.Sales;
  return d;
}).then(data => {
  x.domain(d3.extent(data, d => d.date));
  y.domain([0, d3.max(data, d => d.sales)]);
  
  g.append("path")
      .datum(data)
      .attr("class", "area")
      .attr("d", area);
  
  g.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x));

  g.append("g")
      .call(d3.axisLeft(y));

  // Add labels
  svg.append("text")
    .attr("transform", "translate(" + (width/2) + " ," + (height + margin.top + 30) + ")")
    .style("text-anchor", "middle")
    .text("Date");

  svg.append("text")
    .attr("transform", "rotate(-90)")
    .attr("y", 0 - margin.left)
    .attr("x",0 - (height / 2))
    .attr("dy", "1em")
    .style("text-anchor", "middle")
    .text("Sales ($)");
});
